package com.caimei365.manager.dao.user;

import com.caimei365.manager.entity.caimei.CmShop;
import com.caimei365.manager.entity.caimei.cmUser.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/9/5
 */
@Mapper
public interface CustomerServiceDao {
    /**
     * 潜客供应商列表
     * @param cmShopStatistics
     * @return
     */
    List<CmShopStatistics> getCustomerShopList(CmShopStatistics cmShopStatistics);

    /**
     * 潜客供应商Id集合
     * @return
     */
    List<Integer> getCustomerShopId();

    /**
     * 供应商列表
     * @param shopName
     * @return
     */
    List<CmShop> getShopList(@Param("shopName") String shopName, @Param("shopId") Integer shopId);

    /**
     * 添加供应商
     * @param cmShopStatistics
     */
    void insertCustomerShop(CmShopStatistics cmShopStatistics);

    /**
     * 修改统计状态
     * @param id
     * @param status
     */
    void updateCustomerShop( @Param("id") Integer id, @Param("status") Integer status);

    /**
     * 游客统计列表
     * @param cmRoosInformation
     * @return
     */
    List<CmRoosInformation> getCmInformationList(CmRoosInformation cmRoosInformation);

    /**
     * 修改跟进状态
     * @param id
     * @param followUpStatus
     */
    void updateInformation(@Param("id") Integer id, @Param("followUpStatus") Integer followUpStatus, @Param("serviceProviderId") Integer serviceProviderId);

    /**
     * 添加游客备注
     * @param cmInformationNotes
     */
    void insertInformationNote(CmInformationNotes cmInformationNotes);

    /**
     * 添加游客备注图片
     * @param cmInformationNotesImage
     */
    void insertInformationNoteImage(CmInformationNotesImage cmInformationNotesImage);

    /**
     * 查询游客备注
     * @param informationId
     * @return
     */
    List<CmInformationNotes> getInformationNotes(@Param("informationId") Integer informationId);

    /**
     * 游客备注图片
     * @param informationNoteId
     * @return
     */
    List<String> getinformationNotesImage(@Param("informationNoteId") Integer informationNoteId);

    /**
     * 相关文章列表
     * @param cmShopInfo
     * @return
     */
    List<CmShopInfo> getShopInfoList(CmShopInfo cmShopInfo);

    /**
     * 已被选择文章集合
     * @return
     */
    List<Integer> getShopInfoId();

    /**
     * 选择文章
     * @param id
     * @param title
     * @return
     */
    List<Info> getInfoList(@Param("id")Integer id, @Param("title") String title);

    /**
     * 插入供应商相关文章统计
     * @param cmShopInfo
     */
    void insertShopInfo(CmShopInfo cmShopInfo);

    /**
     * 修改统计状态
     * @param id
     * @param status
     */
    void updateShopInfoStatus(@Param("id") Integer id, @Param("status") Integer status);

    /**
     * 删除统计文章
     * @param id
     */
    void delShopInfo(@Param("id") Integer id);

    /**
     * 相关搜索词统计列表
     * @param cmShopKeyword
     * @return
     */
    List<CmShopKeyword> getShopKeyword(CmShopKeyword cmShopKeyword);

    /**
     * 相关搜索词统计Id
     * @return
     */
    List<Integer> getShopKeywordId();

    /**
     * 选择搜索词
     * @param keyword
     * @return
     */
    List<CmUserSearchFrequency> getSearchFrequencyList(@Param("keyword") String keyword);

    /**
     * 插入相关搜索词统计
     * @param cmShopKeyword
     */
    void insertShopKeyword(CmShopKeyword cmShopKeyword);

    /**
     * 修改统计状态
     * @param id
     * @param status
     */
    void updateShopKeywordStatus(@Param("id") Integer id, @Param("status") Integer status);

    /**
     * 删除相关搜索词
     * @param id
     */
    void delShopKeyword(@Param("id") Integer id);

    /**
     * 弹框数据回显
     * @param shopId
     * @return
     */
    CmShopPopUp getShopPopUp(@Param("shopId") Integer shopId);

    /**
     * 插入弹框数据
     * @param cmShopPopUp
     */
    void insertShopPopUp(CmShopPopUp cmShopPopUp);

    /**
     * 修改弹框数据
     * @param cmShopPopUp
     */
    void updateShopPopUp(CmShopPopUp cmShopPopUp);

    /**
     * 供应商广告列表
     * @param cmShopAdvertisingImage
     * @return
     */
    List<CmShopAdvertisingImage> getShopAdvertisingImage(CmShopAdvertisingImage cmShopAdvertisingImage);

    /**
     * 广告信息回显
     * @return
     */
    CmShopAdvertisingImage getShopAdvertisingImageById(@Param("id") Integer id);

    /**
     * 插入广告信息
     * @param cmShopAdvertisingImage
     */
    void insertShopAdvertisingImage(CmShopAdvertisingImage cmShopAdvertisingImage);

    /**
     * 编辑广告信息
     * @param cmShopAdvertisingImage
     */
    void updateShopAdvertisingImage(CmShopAdvertisingImage cmShopAdvertisingImage);

    /**
     * 排序
     * @param id
     * @param sort
     */
    void updateShopAdvertisingImageSort(@Param("id") Integer id, @Param("sort") Integer sort);

    /**
     * 修改上下架状态
     * @param id
     * @param status
     */
    void updateShopAdvertisingImageStatus(@Param("id") Integer id, @Param("status") Integer status);

    /**
     * 删除广告
     * @param id
     */
    void delShopAdvertisingImage(@Param("id") Integer id);

    /**
     * 供应商主页统计
     * @param shopId
     * @param startTime
     * @param endTime
     * @return
     */
    List<CmPageShop> getPageShop(@Param("shopId") Integer shopId, @Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 供应商商品统计
     * @param shopId
     * @return
     */
    List<CmPageShopProduct> getPageShopProduct(@Param("shopId") Integer shopId, @Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 供应商文章
     * @param shopId
     * @return
     */
    List<CmPageShopInfo> getPageShopInfo(@Param("shopId") Integer shopId, @Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 供应商搜索词统计
     * @param shopId
     * @return
     */
    List<CmPageShopKeyword> getPageShopKeyword(@Param("shopId") Integer shopId, @Param("startTime") String startTime, @Param("endTime") String endTime);

}
