package com.caimei365.manager.service.caimei.user.impl;

import com.alibaba.fastjson.JSONObject;
import com.caimei.utils.AppUtils;
import com.caimei.utils.MathUtil;
import com.caimei365.manager.dao.user.CmClubRemarksDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.cmUser.*;
import com.caimei365.manager.service.caimei.CmOssArchiveService;
import com.caimei365.manager.service.caimei.user.CmClubRemarksService;
import com.caimei365.manager.utils.OSSUtils;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.codehaus.jackson.map.ObjectMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/9/7
 */
@Slf4j
@Service
public class CmClubRemarksServiceImpl implements CmClubRemarksService {

    @Resource private CmClubRemarksDao cmClubRemarksDao;
    @Resource private CmOssArchiveService cmOssArchiveService;
    @Resource private OSSUtils ossUtils;

    /**
     * 咨询记录类别
     * @return
     */
    @Override
    public ResponseJson<List<CmConsulttype>> getClassName() {
        List<CmConsulttype> className = cmClubRemarksDao.getClassName();
        return ResponseJson.success(className);
    }

    /**
     * 获取当天协销咨询记录信息
     * @param startTime
     * @param endTime
     * @return
     */
    @Override
    public ResponseJson<Map<String, Object>> getServiceList(String startTime, String endTime) {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
        // 格式时间
        if (StringUtils.isNotBlank(startTime) && StringUtils.isNotBlank(endTime)) {
            try {
                Date startDate = dateFormat.parse(startTime);
                Date endDate = dateFormat.parse(endTime);
                startTime = dateFormat.format(startDate) + " 00:00:00";
                endTime = dateFormat.format(endDate) + " 23:59:59";
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        // 协销数据
        List<ServiceProviderModel> serviceList = cmClubRemarksDao.getServiceList();
        // 注册咨询记录总数
        AtomicInteger registeredNumber = new AtomicInteger(0);
        // 未注册咨询记录总数
        AtomicInteger unRegisteredNumber = new AtomicInteger(0);
        for (ServiceProviderModel s : serviceList){
            // 已注册用户咨询记录
            s.setRegisteredNumber(cmClubRemarksDao.getRegisteredNumber(s.getServiceProviderId(), startTime, endTime));
            // 未注册用户咨询记录
            s.setUnregisteredNumber(cmClubRemarksDao.getUnregisteredNumber(s.getServiceProviderId(), startTime, endTime));
            registeredNumber.set(MathUtil.add(registeredNumber.get(), s.getRegisteredNumber()).intValue());
            unRegisteredNumber.set(MathUtil.add(unRegisteredNumber.get(), s.getUnregisteredNumber()).intValue());
        }
        // 全部协销的数据
        ServiceProviderModel service = new ServiceProviderModel();
        service.setName("全部");
        service.setLinkMan("全部");
        service.setRegisteredNumber(registeredNumber.get());
        service.setUnregisteredNumber(unRegisteredNumber.get());
        // 在首位加入总数数据
        serviceList.add(0, service);
        Map<String, Object> map = new HashMap<>();
        map.put("serviceList", serviceList);
        map.put("registeredNumber", registeredNumber.get());
        map.put("unRegisteredNumber", unRegisteredNumber.get());
        map.put("number", MathUtil.add(registeredNumber.get(), unRegisteredNumber.get()).intValue());
        return ResponseJson.success(map);
    }

    /**
     * 已注册用户咨询记录
     *
     * @param cmClubRemarks
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<CmClubRemarks>> findRegistList(CmClubRemarks cmClubRemarks, Integer pageNum, Integer pageSize) {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
        // 格式时间
        if (StringUtils.isNotBlank(cmClubRemarks.getStartTime()) && StringUtils.isNotBlank(cmClubRemarks.getEndTime())) {
            try {
                Date startDate = dateFormat.parse(cmClubRemarks.getStartTime());
                Date endDate = dateFormat.parse(cmClubRemarks.getEndTime());
                cmClubRemarks.setStartTime(dateFormat.format(startDate) + " 00:00:00");
                cmClubRemarks.setEndTime(dateFormat.format(endDate) + " 23:59:59");
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        PageHelper.startPage(pageNum, pageSize);
        List<CmClubRemarks> remarksList = cmClubRemarksDao.findRegistList(cmClubRemarks);
        remarksList.forEach(remarks -> {
            if (StringUtils.isNotBlank(remarks.getConsult())) {
                StringBuilder cons = new StringBuilder();
                if (remarks.getConsult().contains(",")) {
                    String[] split = remarks.getConsult().split(",");
                    for (String string : split) {
                        cons.append(cmClubRemarksDao.findClassName(string)).append(",");
                    }
                    cons = new StringBuilder(cons.substring(0, cons.length() - 1));
                } else {
                    cons = new StringBuilder(cmClubRemarksDao.findClassName(remarks.getConsult()));
                }
                remarks.setConsultType(cons.toString());
            }
            List<String> remarkList = new ArrayList<>();
            // 合并标签
            if (StringUtils.isNotBlank(remarks.getRemarks())) {
                if (remarks.getRemarks().contains(",")) {
                    String[] split = remarks.getRemarks().split(",");
                    remarkList.addAll(Arrays.asList(split));
                } else {
                    remarkList.add(remarks.getRemarks());
                }
            }
            if (StringUtils.isNotBlank(remarks.getTrendsKeyword())) {
                if (remarks.getTrendsKeyword().contains(",")) {
                    String[] split = remarks.getTrendsKeyword().split(",");
                    remarkList.addAll(Arrays.asList(split));
                } else {
                    remarkList.add(remarks.getTrendsKeyword());
                }
            }
            if (StringUtils.isNotBlank(remarks.getStateKeyword())) {
                if (remarks.getStateKeyword().contains(",")) {
                    String[] split = remarks.getStateKeyword().split(",");
                    remarkList.addAll(Arrays.asList(split));
                } else {
                    remarkList.add(remarks.getStateKeyword());
                }
            }
            remarks.setRemarks(StringUtils.strip(remarkList.toString(), "[]"));
            List<String> imageList = null;
            List<RemarksFileVo> fileList = null;
            if (1 == remarks.getType()) {
                // 已注册用户
                imageList = cmClubRemarksDao.getRemarksImageList(remarks.getRemarksId());
                fileList = cmClubRemarksDao.getRemarksFileList(remarks.getRemarksId());
            } else {
                // 未注册用户
                imageList = cmClubRemarksDao.getVisitorImageList(remarks.getRemarksId());
                fileList = cmClubRemarksDao.getVisitorFileList(remarks.getRemarksId());
            }
            fileList.forEach(f -> f.setFileUrl(ossUtils.getOssUrl(f.getOssName())));
            if (StringUtils.isNotBlank(remarks.getMainImage())) {
                remarks.setMainImage(AppUtils.getImageURL("product", remarks.getMainImage(), 0, ""));
            }
            remarks.setImageList(imageList);
            remarks.setFileList(fileList);
            // 咨询商品信息
            if (null != remarks.getProductId()) {
                remarks.setProduct(cmClubRemarksDao.getProduct(remarks.getProductId()));
            }
            // 报备记录
            if (null != remarks.getReportId()) {
                remarks.setReports(cmClubRemarksDao.getReportById(remarks.getReportId()));
            }
        });
        PaginationVo<CmClubRemarks> page = new PaginationVo<>(remarksList);
        return ResponseJson.success(page);
    }

    /**
     * 文件下载
     *
     * @param fileName
     * @param ossName
     * @param request
     * @param response
     * @return
     */
    @Override
    public void downloadRemarks(String fileName, String ossName, HttpServletRequest request, HttpServletResponse response)  throws IOException {

        log.info("fileName==="+fileName+"===ossName==="+ossName);
        ossUtils.downFile(ossName, fileName);
        cmOssArchiveService.download(request, response, fileName);
    }

    /**
     * 报备列表
     *
     * @param cmReport
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<CmReport>> getReportList(CmReport cmReport, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmReport> list = cmClubRemarksDao.getReportList(cmReport);
        PaginationVo<CmReport> page = new PaginationVo<>(list);
        return ResponseJson.success(page);
    }

    /**
     * 报备列表查看详情
     *
     * @param cmClubRemarks
     * @return
     */
    @Override
    public ResponseJson<List<CmClubRemarks>> cmRegistReportList(CmClubRemarks cmClubRemarks) {
        List<CmClubRemarks> registList = cmClubRemarksDao.findRegistList(cmClubRemarks);
        registList.forEach(remarks -> {
            if (StringUtils.isNotBlank(remarks.getConsult())) {
                StringBuilder cons = new StringBuilder();
                if (remarks.getConsult().contains(",")) {
                    String[] split = remarks.getConsult().split(",");
                    for (String string : split) {
                        cons.append(cmClubRemarksDao.findClassName(string)).append(",");
                    }
                    cons = new StringBuilder(cons.substring(0, cons.length() - 1));
                } else {
                    cons = new StringBuilder(cmClubRemarksDao.findClassName(remarks.getConsult()));
                }
                remarks.setConsultType(cons.toString());
            }
            List<String> imageList = cmClubRemarksDao.getRemarksImageList(remarks.getRemarksId());
            List<RemarksFileVo> fileList = cmClubRemarksDao.getRemarksFileList(remarks.getRemarksId());
            fileList.forEach(f -> f.setFileUrl(ossUtils.getOssUrl(f.getOssName())));
            if (StringUtils.isNotBlank(remarks.getMainImage())) {
                remarks.setMainImage(AppUtils.getImageURL("product", remarks.getMainImage(), 0, ""));
            }
            remarks.setImageList(imageList);
            remarks.setFileList(fileList);
            // 咨询商品信息
            if (null != remarks.getProductId()) {
                remarks.setProduct(cmClubRemarksDao.getProduct(remarks.getProductId()));
            }
            // 报备记录
            if (null != remarks.getReportId()) {
                remarks.setReports(cmClubRemarksDao.getReportById(remarks.getReportId()));
            }
        });
        return ResponseJson.success(registList);
    }

    /**
     * 取消关联
     *
     * @param remarksId
     * @param type
     * @return
     */
    @Override
    public ResponseJson audit(Integer remarksId, Integer type) {
        if (type == 1) {
            cmClubRemarksDao.updateClubRemarks(remarksId);
        } else {
            cmClubRemarksDao.updateVisitorRemarks(remarksId);
        }
        return ResponseJson.success();
    }

    /**
     * 删除报备列表
     *
     * @param reportId
     * @return
     */
    @Override
    public ResponseJson deleteReport(Integer reportId) {
        // 已注册咨询记录数
        Integer clubCount = cmClubRemarksDao.clubRemarksConut(reportId);
        // 未注册咨询记录数
        Integer visitorCount = cmClubRemarksDao.visitorRemarksConut(reportId);
        if (MathUtil.add(clubCount, visitorCount).intValue() > 0) {
            return ResponseJson.error(-1, "请将该报备关联的全部咨询记录取消关联后再删除", null);
        } else {
            cmClubRemarksDao.deleteClubRemarks(reportId);
        }
        return ResponseJson.success();
    }

    /**
     * 审核
     *
     * @param reportId
     * @param auditName
     * @param auditText
     * @param status
     * @return
     */
    @Override
    public ResponseJson reportCount(Integer reportId, String auditName, String auditText, Integer status) {
        // 已注册咨询记录数
        Integer clubCount = cmClubRemarksDao.clubRemarksConut(reportId);
        // 未注册咨询记录数
        Integer visitorCount = cmClubRemarksDao.visitorRemarksConut(reportId);
        if (MathUtil.add(clubCount, visitorCount).intValue() > 0) {
            cmClubRemarksDao.updateAuditRemarks(reportId, auditName, auditText, status);
        } else {
            return ResponseJson.error(-1, "该报备未关联任何咨询记录，无需审核。", null);
        }
        return ResponseJson.success();
    }

    /**
     * 咨询记录类别
     *
     * @param cmConsulttype
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<CmConsulttype>> getConsultList(CmConsulttype cmConsulttype, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmConsulttype> consultList = cmClubRemarksDao.getConsultList(cmConsulttype);
        PaginationVo<CmConsulttype> page = new PaginationVo<>(consultList);
        return ResponseJson.success(page);
    }

    /**
     * 保存咨询记录类别
     *
     * @param cmConsulttype
     * @return
     */
    @Override
    public ResponseJson saveConsult(CmConsulttype cmConsulttype) {
        if (null == cmConsulttype.getId()) {
            // 添加
            cmClubRemarksDao.insertConsult(cmConsulttype);
        } else {
            // 修改
            cmClubRemarksDao.updateConsult(cmConsulttype);
        }
        return ResponseJson.success();
    }

    /**
     * 删除咨询记录类别
     *
     * @param id
     * @return
     */
    @Override
    public ResponseJson deleteConsult(Integer id) {
        cmClubRemarksDao.deleteConsult(id);
        return ResponseJson.success();
    }

    /**
     * 排序
     *
     * @param sortNumber
     * @return
     */
    @Override
    public ResponseJson sort(Integer id, Integer sortNumber) {
        CmConsulttype cmConsulttype = new CmConsulttype();
        cmConsulttype.setId(id);
        cmConsulttype.setSortNumber(sortNumber);
        cmClubRemarksDao.updateConsult(cmConsulttype);
        return ResponseJson.success();
    }

    /**
     * 未注册用户咨询记录
     *
     * @param visit
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<VisitRemarkVo>> visitRemarkList(VisitRemarkVo visit, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<VisitRemarkVo> visitRemarkList = cmClubRemarksDao.getVisitRemarkList(visit);
        PaginationVo<VisitRemarkVo> page = new PaginationVo<>(visitRemarkList);
        return ResponseJson.success(page);
    }

    /**
     * 未注册用户数据详情
     *
     * @param visitRemarkVo
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public ResponseJson<PaginationVo<CmClubRemarks>> remarksList(VisitRemarkVo visitRemarkVo, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmClubRemarks> remarksList = cmClubRemarksDao.getClubRemarksList(visitRemarkVo);
        remarksList.forEach(remarks -> {
            if (StringUtils.isNotBlank(remarks.getConsult())) {
                StringBuilder cons = new StringBuilder();
                if (remarks.getConsult().contains(",")) {
                    String[] split = remarks.getConsult().split(",");
                    for (String string : split) {
                        cons.append(cmClubRemarksDao.findClassName(string)).append(",");
                    }
                    cons = new StringBuilder(cons.substring(0, cons.length() - 1));
                } else {
                    cons = new StringBuilder(cmClubRemarksDao.findClassName(remarks.getConsult()));
                }
                remarks.setConsultType(cons.toString());
            }
            List<String> imageList = null;
            List<RemarksFileVo> fileList = null;
            List<String> remarkList = new ArrayList<>();
            // 合并标签
            if (StringUtils.isNotBlank(remarks.getRemarks())) {
                if (remarks.getRemarks().contains(",")) {
                    String[] split = remarks.getRemarks().split(",");
                    remarkList.addAll(Arrays.asList(split));
                } else {
                    remarkList.add(remarks.getRemarks());
                }
            }
            if (StringUtils.isNotBlank(remarks.getTrendsKeyword())) {
                if (remarks.getTrendsKeyword().contains(",")) {
                    String[] split = remarks.getTrendsKeyword().split(",");
                    remarkList.addAll(Arrays.asList(split));
                } else {
                    remarkList.add(remarks.getTrendsKeyword());
                }
            }
            if (StringUtils.isNotBlank(remarks.getStateKeyword())) {
                if (remarks.getStateKeyword().contains(",")) {
                    String[] split = remarks.getStateKeyword().split(",");
                    remarkList.addAll(Arrays.asList(split));
                } else {
                    remarkList.add(remarks.getStateKeyword());
                }
            }
            remarks.setRemarks(StringUtils.strip(remarkList.toString(), "[]"));
            if (1 == remarks.getType()) {
                // 已注册用户
                imageList = cmClubRemarksDao.getRemarksImageList(remarks.getRemarksId());
                fileList = cmClubRemarksDao.getRemarksFileList(remarks.getRemarksId());
            } else {
                // 未注册用户
                imageList = cmClubRemarksDao.getVisitorImageList(remarks.getRemarksId());
                fileList = cmClubRemarksDao.getVisitorFileList(remarks.getRemarksId());
            }
            fileList.forEach(f -> f.setFileUrl(ossUtils.getOssUrl(f.getOssName())));
            remarks.setImageList(imageList);
            remarks.setFileList(fileList);
            // 咨询商品信息
            if (null != remarks.getProductId()) {
                remarks.setProduct(cmClubRemarksDao.getProduct(remarks.getProductId()));
            }
            // 报备记录
            if (null != remarks.getReportId()) {
                remarks.setReports(cmClubRemarksDao.getReportById(remarks.getReportId()));
            }
        });
        PaginationVo<CmClubRemarks> page = new PaginationVo<>(remarksList);
        return ResponseJson.success(page);
    }

}
